@@ -19,6 +19,10 @@ library(mrgsolve)
 library(ggridges)
 library(table1)
 library(data.table)
+library(ggh4x)
+library(ggpmisc)
+library(quantreg)
+
 theme_set(theme_bw())
 nsubj <- 1000
 
@@ -86,15 +90,18 @@ outputsim <- pedmodsim %>%
 outputsim$SEX <- as.factor(outputsim$SEX)
 outputsim$SEX <- factor(outputsim$SEX, labels=c("Girls","Boys"))
 
-p1 <- ggplot(data = outputsim[outputsim$SEX=="Girls",],
-       aes(time, CP, group = ID)) +
+p1 <- ggplot(data = outputsim[,],
+             aes(time, CP, group = ID)) +
   geom_line(alpha = 0.2, size = 0.1) +
   facet_grid(AGE ~ WT+SEX,
-             labeller = label_both) +
-  scale_y_log10() +
+             labeller = label_both , switch ="y") +
+  scale_y_log10(breaks =c(0.001,0.01,0.01,0.1,1,10),
+                labels = c("0.001","0.01","0.01","0.1","1","10")) +
   labs(y = expression(Log[10]~~Plasma~~Concentrations), color = "Sex", x = "Time (h)")
 p1
 
+
+
 ## ----ncapedpkmodel, collapse=TRUE---------------------------------------------
 derive.exposure <- function(time, CP) {
   n <- length(time)
@@ -119,7 +126,7 @@ yvar_names <- c(
   'AUC'="AUC",
   'Cmax'="Cmax"
 )
-p4 <- ggplot(refbsv[SEX=="Girls",], aes(
+p4 <- ggplot(refbsv[,], aes(
         x      = stdparamvalue,
         y      = paramname,
         fill   = factor(..quantile..),
@@ -152,21 +159,15 @@ p4 <- ggplot(refbsv[SEX=="Girls",], aes(
 
 p4
 
-## ----ped2, fig.width=7,fig.height=4, include=FALSE----------------------------
- # p1<- p1 +theme_bw(base_size=18)
- # p4 <- p4+ theme_bw(base_size=18)+
- #   theme(axis.text.y=element_blank(),axis.ticks.y = element_blank(),
- #           legend.position = "none")
- # (p1 + p4)
- # 
- # ggsave("Figure_7_1.png", device="png",type="cairo-png",
- #        dpi=125, width =9 ,height=4)
+# p1<- p1 +theme_bw(base_size=18)
+# p4 <- p4+ theme_bw(base_size=18)+
+#   theme(axis.text.y=element_blank(),axis.ticks.y = element_blank(),
+#         legend.position = "none")
+# egg::ggarrange(p1 , p4,ncol=2)
+
 
 ## ----simcovariate, collapse=TRUE----------------------------------------------
-wtage <- read.csv (url("https://www.cdc.gov/growthcharts/data/zscore/wtage.csv"))
-#boys 1 and girls 2 in this file
 wtage<-  wtage[wtage$Agemos<=6*12,] # keeps only 2 to 6 years
-
 wtage[wtage$Agemos>=4*12-1&wtage$Agemos<=4*12 +1,] %>%
   group_by(Sex) %>% 
   summarize(Median=median(M))
@@ -175,6 +176,7 @@ nweightsperage <- 50 # simulate 50 kid at each age/sex
 simwtageoutput <- data.frame(matrix(NA, nrow = nrow(wtage),ncol = nweightsperage))
 names(simwtageoutput) <- paste0("Var", 1:nweightsperage)
 set.seed(209321)
+wtage <- as.data.frame(wtage)
 for (i in 1:nrow(wtage)) {#
   simpoints <- gamlss.dist::rBCCG(nweightsperage,
                                   mu = wtage[i,"M"],
@@ -206,7 +208,6 @@ data.all<-merge(idata,data.dose)
 data.all$ID <- 1: nrow(data.all)
 outcovcomb<- pedmodsim %>%
   data_set(data.all) %>%
-  zero_re() %>% 
   mrgsim(end=24, delta=1)
 outcovcomb<-as.data.frame(outcovcomb)
 outcovcomb <- outcovcomb %>% 
@@ -230,7 +231,7 @@ labs(y = "Plasma Concentrations", color = "Sex", x = "Time (h)")+
   guides(colour=guide_legend(override.aes = list(alpha=1,size=0.5)))
  p3
 
-## ----simcovariatemodelpkparam, collapse=TRUE----------------------------------
+## ----simcovariatemodelpkparam, collapse=TRUE, fig.height= 6, fig.width=8------
 out.df.multivariatecov <- as.data.frame(outcovcomb) %>% 
   arrange(ID,time) %>% 
   group_by(ID,SEX,AGE,WT)%>% 
@@ -242,55 +243,60 @@ out.df.multivariatecov.long <- out.df.multivariatecov %>%
   group_by (paramname,SEX) %>%
   mutate(medparam = median(paramvalue),
          paramvalue = paramvalue / medparam) 
-out.df.multivariatecov.long$SEXLABEL <- factor(out.df.multivariatecov.long$SEX,labels=c("Girls","Boys"))
+out.df.multivariatecov.long$SEXLABEL <- factor(out.df.multivariatecov.long$SEX,
+                                               labels=c("Girls","Boys"))
 
-paramvsage <-  ggplot(out.df.multivariatecov.long,
-         aes( AGE,paramvalue,col=SEXLABEL) )+
-  geom_point(alpha=0.1,size=2)+
-  facet_grid(paramname~SEXLABEL,labeller = label_value,
-             scales="free_y")+
-    labs(y="Standardized PK Parameter Values",x="Age (years)",color="")
-paramvsage  
-paramvswt <-    ggplot(out.df.multivariatecov.long,
-         aes( WT,paramvalue,col=factor(SEXLABEL)) )+
-  geom_point(alpha=0.1,size=2)+
-  facet_grid(paramname~SEXLABEL,labeller = label_value,
-             scales="free_y")+
-    labs(y="Standardized PK Parameter Values",x="Weight (kg)",color="")
-paramvswt   
-
-## ---- fig.width=7 ,message=FALSE, include=FALSE-------------------------------
-# p3 <- p3+ theme_bw(base_size = 18)+
-#   theme(strip.placement = "outside",legend.position =c(0.9,0.2),
-#   legend.background = element_blank())+
-#   guides(colour=guide_legend(override.aes = list(alpha=1,size=0.5)))
-# 
-# wtvsageplot2<-  wtvsageplot +theme_bw(base_size=18) + facet_grid(SEXLABEL~.,switch="y")+theme(legend.position = "none")
-#  png("Figure_7_2.png", type="cairo-png",width= 2*7*72, height =5*72)
-#  egg::ggarrange(wtvsageplot2 ,p3,widths = c(1,3),ncol=2)
-#   dev.off()
-# 
-# wtvsageplot<- wtvsageplot +theme_bw(base_size=18)+theme(legend.position = "none")
-# wtvsageplot
-# ggsave("Figure_6_1.png", device="png",type="cairo-png",
-#        width= 6, height = 5,dpi=72)
-# 
-#  paramvsage<- paramvsage+theme_bw(base_size=18)+theme(legend.position = "none")
-#  paramvswt<- paramvswt+theme_bw(base_size=18)+theme(legend.position = "none")
-# (paramvswt/paramvsage)
-# ggsave("Figure_6_2.png", device="png",type="cairo-png",width= 6, height = 9,dpi=72)
-
-## ----computenca, fig.height=5, collapse=TRUE----------------------------------
 nca.summaries <- out.df.multivariatecov.long %>%
-  mutate(SEXCAT =ifelse( SEX=="Boys","Girls","Boys"),
-         REF = "All Subjects")
+  mutate(REF = "All Subjects")
 
 nca.summaries$WTCAT3 <- table1::eqcut( nca.summaries$WT,3,varlabel = "Weight")
 nca.summaries$WTCAT4 <- table1::eqcut( nca.summaries$WT,4,varlabel = "Weight")
 nca.summaries$AGECAT4 <- table1::eqcut( nca.summaries$AGE,4,varlabel = "Age")
+
+nca.summaries$AGECAT4_label <- nca.summaries$AGECAT4 
+
+
+f <- function(x, xcat, which, what, from, to, ...) {
+  what <- sub("of ", "of\n", what)
+  what <- sub("median ", "median\n", what)
+  sprintf("%s %s [%s to %s[",
+          which, what, signif_pad(from, 3, FALSE), signif_pad(to, 3, FALSE))
+ }
+
+
+plot1 <-    ggplot(nca.summaries %>% 
+                    filter(WT<=25) %>%
+                    filter(WT>12) %>%
+                    gather(key,value,WT,AGE) %>% 
+                    mutate(key = ifelse(key=="WT","Weight (kg)", "Age (years)")) ,
+                  aes(x=value,y=paramvalue,fill= SEX))+
+  annotate("rect",
+           ymin  = 0.6,
+           ymax  = 1.4,
+           xmin  = -Inf,
+           xmax  = Inf,
+           fill  = "gray",
+           alpha = 0.4) +
+  geom_hline(data=data.frame (yintercept=1),  aes(yintercept =yintercept  ),size = 1)+
+  geom_point(alpha = 0.2, size = 1) +
+  stat_quant_band(method = "rqss",formula = y ~ qss(x, lambda = 2),
+                   quantiles = c(0.05, 0.5, 0.95), col = "black",aes(fill=SEX))+
+   facet_nested(SEX~paramname+key,scales="free",switch = "both")+
+  #stat_quantile()+
+  #facet_grid(SEX~key,scales="free",switch = "both")+
+  theme_bw(base_size = 18)+
+  labs(x="",y="Standardized PK Exposure", fill ="Smoothed 90%\nquantreg intervals")+
+  theme(strip.placement = "outside",legend.position = "none",axis.title.x = element_blank())+
+  scale_y_log10(  breaks =c(0.25,0.5,1,2))+
+  coord_cartesian(ylim=c(0.25,2))
+
+plot1
+
+
+## ----computenca, fig.height=5, collapse=TRUE----------------------------------
 nca.summaries.long <- gather(nca.summaries,
                              covname,
-                             covvalue,REF,WTCAT3,WTCAT4,AGECAT4,SEXCAT,
+                             covvalue,REF,WTCAT3,WTCAT4,AGECAT4,SEX,
                              factor_key = TRUE)
 nca.summaries.long$covvalue <- as.factor( nca.summaries.long$covvalue)
 nca.summaries.long$covvalue <- reorder(nca.summaries.long$covvalue,nca.summaries.long$paramvalue)
@@ -318,10 +324,6 @@ ggridgesplot<- ggplot(nca.summaries.long,
    labs(x="Effects Of Covariates on PK Parameter",y="")
 ggridgesplot
 
-## ---- fig.width=7 ,message=FALSE, include=FALSE-------------------------------
-# ggridgesplot+theme(legend.position = "none")
-# ggsave("Figure_7_3.png", device="png",type="cairo-png",width= 7.8, height = 6,dpi=72)
-
 ## ----simcovariate2, collapse=TRUE---------------------------------------------
 coveffectsdatacovrep <- nca.summaries.long %>% 
   dplyr::group_by(paramname,covname,covvalue) %>% 
@@ -330,9 +332,14 @@ coveffectsdatacovrep <- nca.summaries.long %>%
     lower= quantile(paramvalue,0.05),
     upper = quantile(paramvalue,0.95)) %>% 
   dplyr::filter(!is.na(mid)) %>% 
-  dplyr::filter(covname !="WTCAT3")
+  dplyr::filter(covname !="WTCAT4")
 
-bsvranges <- bsvranges[SEX=="Girls",]
+bsvranges <- refbsv[,list(
+    P05 = quantile(stdparamvalue, 0.05),
+    P25 = quantile(stdparamvalue, 0.25),
+    P50 = quantile(stdparamvalue, 0.5),
+    P75 = quantile(stdparamvalue, 0.75),
+    P95 = quantile(stdparamvalue, 0.95)), by = list(paramname)]
 
 setkey(bsvranges, paramname)
 
@@ -349,12 +356,11 @@ coveffectsdatacovrepbsv2$label <-    "50% of patients"
 coveffectsdatacovrepbsv2$lower <- bsvranges$P25
 coveffectsdatacovrepbsv2$upper <- bsvranges$P75
 
-coveffectsdatacovrepbsv<- rbind(coveffectsdatacovrep,coveffectsdatacovrepbsv2,
-                                coveffectsdatacovrepbsv)
+coveffectsdatacovrepbsv <- coveffectsdatacovrep
 
 coveffectsdatacovrepbsv <- coveffectsdatacovrepbsv %>% 
   mutate(
-    label= covvalue,
+    label = covvalue,
     LABEL = paste0(format(round(mid,2), nsmall = 2),
                    " [", format(round(lower,2), nsmall = 2), "-",
                    format(round(upper,2), nsmall = 2), "]"))
@@ -363,30 +369,30 @@ coveffectsdatacovrepbsv<- as.data.frame(coveffectsdatacovrepbsv)
 coveffectsdatacovrepbsv$label <- gsub(": ", ":\n", coveffectsdatacovrepbsv$label)
 
 coveffectsdatacovrepbsv$covname <-factor(as.factor(coveffectsdatacovrepbsv$covname ),
-levels =  c("WTCAT4","AGECAT4","SEXCAT","REF", "BSV"),
-labels = c("Weight","Age","Sex","REF","BSV"))
-    
+                  levels =  c("WTCAT3","AGECAT4","SEX","REF"),
+                   labels = c("Weight\nSplits","Age\nSplits","Sex\nSplits","All"))
 
+
+coveffectsdatacovrepbsv$label <- factor(coveffectsdatacovrepbsv$label)
 coveffectsdatacovrepbsv$label <- factor(coveffectsdatacovrepbsv$label,
-levels =c(
-   "1st quartile of Age:\n[2.00,2.96)"
- , "2nd quartile of Age:\n[2.96,3.96)"
- , "3rd quartile of Age:\n[3.96,4.96)"
- , "4th quartile of Age:\n[4.96,5.96]" 
- , "Boys", "Girls", "All Subjects","90% of patients","50% of patients"
-, "1st quartile of Weight:\n[9.40,13.9)"
-, "2nd quartile of Weight:\n[13.9,15.9)"
-, "3rd quartile of Weight:\n[15.9,18.3)"
-, "4th quartile of Weight:\n[18.3,38.2]"
-))
-
-interval_legend_text = "Median (points)\n90% CI (horizontal lines)"
-interval_bsv_text = "BSV (points)\nPrediction Intervals (horizontal lines)"
+                                        levels =c(
+                                            "1st quartile of Age:\n[2.00,2.96)"
+                                          , "2nd quartile of Age:\n[2.96,3.96)"
+                                          , "3rd quartile of Age:\n[3.96,4.96)"
+                                          , "4th quartile of Age:\n[4.96,5.96]" 
+                                          , "Boys", "Girls", "All Subjects"
+                                          , "1st tertile of Weight:\n[9.40,14.6)"
+                                          , "2nd tertile of Weight:\n[14.6,17.4)"
+                                          , "3rd tertile of Weight:\n[17.4,38.2]"
+                                        ))
+interval_bsv_text = ""
 ref_legend_text = "Reference (vertical line)\nClinically relevant limits\n(gray area)"
+interval_legend_text <- "Median (points)\n90% intervals (horizontal lines) of joint effects:
+covariate distributions, uncertainty\nand between subject variability"
 
 png("./Figure_7_4.png",width = 11 ,height = 7,units = "in",res=72)
 coveffectsplot::forest_plot(coveffectsdatacovrepbsv,
-                            ref_area = c(0.8, 1/0.8),
+                            ref_area = c(0.6, 1/0.6),
                             x_range = c(0.4,2.2),
                             strip_placement = "outside",
                             base_size = 18,
@@ -396,20 +402,21 @@ coveffectsplot::forest_plot(coveffectsdatacovrepbsv,
                             area_legend_text =ref_legend_text ,
                             interval_legend_text = interval_legend_text,
                             interval_bsv_text = interval_bsv_text,
-                            facet_formula = "covname~paramname",
+                            plot_title = "",
+                            legend_shape_reverse = TRUE,
+                            facet_formula = "covname~.",
                             facet_switch = "both",
                             table_facet_switch = "both",
                             reserve_table_xaxis_label_space = TRUE,
                             facet_scales = "free_y", facet_space = "free",
-                            paramname_shape = FALSE,
+                            paramname_shape = TRUE,
                             table_position = "right",
-                            table_text_size=3,
-                            plot_table_ratio = 1.5,
+                            table_text_size= 4,
+                            plot_table_ratio = 5,
                             show_table_facet_strip = "x",
                             show_table_yaxis_tick_label = FALSE,
                             logxscale = TRUE,
                             major_x_ticks = c(0.5,0.8,1/0.8,1/0.5),
                             return_list = FALSE)
-
 dev.off()
 
