@@ -1,103 +1,113 @@
 ## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
+  dev = "png",
   collapse = TRUE,
-  comment = "#>",
-  dev.args = list(png = list(type = "cairo"))
+  message =FALSE,
+  warning =FALSE,
+  fig.width = 7,
+  comment = "#>"
 )
+if (capabilities(("cairo"))) {
+  knitr::opts_chunk$set(dev.args = list(png = list(type = "cairo")))
+}
 library(coveffectsplot)
+library(ggplot2)
+library(ggridges)
+library(tidyr)
 suppressPackageStartupMessages( library(dplyr) )
+nuncertainty <- 10000
+nbsvsubjects <- 100000
 
 
 ## ---- echo=TRUE, results='asis',fig.align = "center",fig.width = 6------------
 set.seed(657687)
 df <- data.frame(
-MASS::mvrnorm(n = 10000,
+MASS::mvrnorm(n = nuncertainty,
                 mu = c(10,0.75,1.5),
-                Sigma=matrix(c((10*0.05)^2,
-                               0.001,0.001,0.001,(0.75*0.05)^2,
-                               0.001,0.001,0.001,(1.5*0.05)^2),3,3,byrow = TRUE) 
+                Sigma=matrix(c((10*0.15)^2,
+                               0.001,0.001,0.001,(0.75*0.15)^2,
+                               0.001,0.001,0.001,(1.5*0.15)^2),3,3,byrow = TRUE) 
 ))
-names(df) <- c("POPCL","dWTdCL","dSEXdCL")
+names(df) <- c("POPCL","dWTdCL","dSexdCL")
 knitr::kable(head(round(df,2),5))
 
 ## ---- echo=FALSE, results='asis',fig.align = "center",fig.width = 6-----------
-dflong <- tidyr::gather(df)
-
-ggplot2::ggplot(dflong,ggplot2::aes(x=value,fill=key))+
-  ggplot2::geom_density(alpha=0.2)+
-    ggplot2::facet_wrap(~key,scales="free",ncol=1)+
-    ggplot2::labs(fill="",x="Uncertainty Distribution of the parameters")+
-  ggplot2::theme(legend.position = "right",legend.background = 
-                   ggplot2::element_rect(fill="transparent"))+
-  ggplot2::guides(fill=ggplot2::guide_legend(reverse = TRUE))
+dflong <- gather(df)
 
+ggplot(dflong,aes(x=value))+
+  geom_density(alpha=0.6, fill = "blue")+
+    facet_wrap(~key,scales="free",ncol=1)+
+    labs(fill="",x="Uncertainty Distribution (RSE 15%) of the Parameters")+
+  theme(legend.position = "none",legend.background = 
+                   element_rect(fill="transparent"),
+                 axis.ticks.y = element_blank(),axis.text.y =element_blank())+
+  guides(fill=guide_legend(reverse = FALSE))
+set.seed(657687)
 dfcov<- data.frame(
-MASS::mvrnorm(n=10000 ,
+MASS::mvrnorm(n=nbsvsubjects,
                 mu =c(65,75),
-                Sigma=matrix(c(15^2,0.01,0.01,15^2),2,2,byrow = TRUE) 
+                Sigma=matrix(c(20^2,0.01,0.01,20^2),2,2,byrow = TRUE) 
 ))
 names(dfcov)<- c("WTWOMAN","WTMAN")
-dfcovlong <- tidyr::gather(dfcov)
-ggplot2::ggplot(dfcovlong,ggplot2::aes(x=value,fill=key))+
-  ggplot2::geom_density(alpha=0.2)+
-  ggplot2::labs(fill="",x="Weight (kg)")+
-  ggplot2::theme(legend.position = "right",legend.background = 
-                   ggplot2::element_rect(fill="transparent"))+
-  ggplot2::guides(fill=ggplot2::guide_legend(reverse = TRUE))
+dfcovlong <- gather(dfcov)
+ggplot(dfcovlong,aes(x=value,linetype=key))+
+  geom_density(alpha=0.2,fill="darkgreen",size=2)+
+  labs(linetype="",x="Weight (kg)")+
+  theme(legend.position = "right",legend.background = 
+                   element_rect(fill="transparent"),axis.ticks.y = element_blank(),axis.text.y =element_blank())+
+  guides(fill=guide_legend(reverse = FALSE))+
+  theme_bw()
 
 
 dfcovlongquantile<- as.data.frame(
-  round(quantile(dfcovlong$value,probs=c(0,0.05,0.25,0.5,0.75,0.95,1)),0)
+  round(quantile(dfcovlong$value,probs=c(0.01,0.05,0.25,0.5,0.75,0.95,0.99)),0)
 )
 names(dfcovlongquantile)<- "Weightquantilevalue"
 dfcovlongquantile$quantile<- rownames(dfcovlongquantile)
 
-
 dfcovlongquantiletable<- t(dfcovlongquantile)
 knitr::kable(dfcovlongquantiletable[1,,drop=FALSE],row.names=FALSE)
 
 ## ---- echo=TRUE,fig.align = "center",fig.width = 6----------------------------
 set.seed(546789)
-CLBSVdistribution <- data.frame(CL= 10*exp(rnorm(10000,0,sd=0.09^0.5)))
+CLBSVdistribution <- data.frame(CL= 10*exp(rnorm(nbsvsubjects,0,sd=0.09^0.5)))
 CLBSVdistribution$CLBSV<- CLBSVdistribution$CL/10
 
-## ---- echo=FALSE,fig.align = "center",fig.width = 6---------------------------
+## ---- echo=FALSE,fig.align = "center",fig.width = 6 ,fig.height=4-------------
 dfbsv<- as.data.frame(
-  round( quantile(CLBSVdistribution$CLBSV,probs=c(0,0.05,0.25,0.5,0.75,0.95,1)),1))
+  round( quantile(CLBSVdistribution$CLBSV,probs=c(0.01,0.05,0.25,0.5,0.75,0.95,0.99)),2))
 names(dfbsv)<- "BSVquantilevalue"
 dfbsv$quantile<- rownames(dfbsv)
-BSVLINE1<- data.frame(
-                       mid = 1,
-                       lower=quantile(CLBSVdistribution$CLBSV,c(0.05)),
-                       upper=quantile(CLBSVdistribution$CLBSV,c(0.95)),
-                       extent="BSV90%")
-
-BSVLINE2<- data.frame( 
-                       mid = 1,
-                       lower=quantile(CLBSVdistribution$CLBSV,c(0.25)),
-                       upper=quantile(CLBSVdistribution$CLBSV,c(0.75)),
-                       extent="BSV50%")
-
-BSVLINE <- rbind(BSVLINE1,BSVLINE2)
-ggplot2::ggplot(data= CLBSVdistribution)+
- ggplot2:: geom_density(ggplot2::aes(x=CLBSV,
-                   col="simomega")) +
-   ggplot2::geom_rect(data=BSVLINE,
-            ggplot2::aes(xmin=lower,xmax=upper  ,
-                fill=extent),ymin=-Inf,ymax=Inf ,
-           alpha=0.1)+
-  ggplot2::geom_vline(xintercept=c(0.8,1,1.25))+
-  ggplot2::theme_bw(base_size = 16)+
-  ggplot2::theme(axis.text.y = ggplot2::element_blank(),
-        axis.ticks.y = ggplot2::element_blank(),
-        axis.text.x=ggplot2::element_text(size=12))+
-  ggplot2::scale_x_continuous(breaks=c(0.25,0.5,0.8,1,1.25,1.5,2,3))+
-  ggplot2::coord_cartesian(xlim=c(0.4,2))+
-  ggplot2::labs(colour="",fill="BSV Coverage",x="BSVCL/Reference CL",
-                title="Illustrating 30% BSV")+
-  ggplot2::guides(fill = ggplot2::guide_legend(override.aes =  list(alpha = 0.1)  ))
-
+CLBSVdistribution$paramname<- "CL"
+bsvplot<-   ggplot(CLBSVdistribution, aes(
+  x      = CLBSV,
+  y      = paramname,
+  fill   = factor(..quantile..),
+  height = ..ndensity..)) +
+  stat_density_ridges(
+    geom="density_ridges_gradient", calc_ecdf=TRUE,
+    quantile_lines=TRUE, rel_min_height=0.001, scale=0.9,
+    quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95)) +
+  scale_fill_manual(
+    name="BSV Ranges",
+    values=c("white", "#FF000050", "#FF0000A0", "#FF0000A0", "#FF000050", "white"),
+    labels = c("(0, 0.05]", "(0.05, 0.25]",
+               "(0.25, 0.5]", "(0.5, 0.75]",
+               "(0.75, 0.95]", "(0.95, 1]")) +
+  theme_bw(base_size = 16) +
+  theme(
+    legend.position = "right",
+    axis.text.y     = element_blank(),
+    axis.ticks.y    = element_blank(),
+    axis.title.y    = element_blank(),
+    axis.text.x=element_text(size=12),
+    axis.title.x=element_text(size=14)) +
+  scale_x_continuous(breaks=c(0.61,0.82,1,1.22,1.63))+
+  coord_cartesian(expand=FALSE,xlim = c(0.49,2.01))+
+  labs(x="Standardized Individual Clearances with BSV",
+                title="Illustrating 30.7% BSV")
 
+bsvplot
 
 dfbsvtable<- t(dfbsv)
 knitr::kable(dfbsvtable[1,,drop=FALSE],row.names=FALSE)
@@ -106,32 +116,51 @@ knitr::kable(dfbsvtable[1,,drop=FALSE],row.names=FALSE)
 
 ## ----fig.width= 7-------------------------------------------------------------
 dfeffects <- df
-dfeffects$REF <- dfeffects$POPCL/ median(dfeffects$POPCL)
-dfeffects$SEX_FEMALE_WT_50 <- dfeffects$REF*(50/70)^dfeffects$dWTdCL
-dfeffects$SEX_FEMALE_WT_90 <-  dfeffects$REF*(90/70)^dfeffects$dWTdCL
-dfeffects$SEX_Male_WT_70 <- dfeffects$dSEXdCL
-dfeffects$SEX_Male_WT_90 <- dfeffects$dSEXdCL*dfeffects$REF*(90/70)^dfeffects$dWTdCL
-dfeffects$BSV<-  CLBSVdistribution$CLBSV
+dfeffects$REFrange <- dfeffects$POPCL/ median(dfeffects$POPCL)
+
+ggplot(dfeffects)+
+  geom_density(aes(x=REFrange,y=..scaled..,col="a.Uncertainty\nRSE=15%"))+
+  geom_density(data=dfcovlong,
+                        aes(x=(value/70)^0.75 ,
+                                y=..scaled..,col="b.Weight\nMean=70 kg, sd=20 kg"))+
+  geom_density(data=CLBSVdistribution ,aes(x=CLBSV,y=..scaled..,
+  col="c.Between subject variability\nCV=30.1%"))+
+  theme_bw(base_size = 16)+
+  theme(axis.text.y = element_blank(),
+        axis.ticks.y = element_blank())+
+  scale_x_continuous(breaks=c(0.25,0.5,0.8,1,1.25,1.5,2,3))+
+  coord_cartesian(xlim=c(0.25,2))+
+  labs(color="",x="Effects Standardized Relative\nto the Typical Value",y= "Scaled Density")+
+  scale_color_manual(values=c("blue","green","red"))
+
+
+## ----fig.width= 7-------------------------------------------------------------
+dfeffects$REF <- 1
+dfeffects$SEX_FEMALE_WT_50 <- (50/70)^dfeffects$dWTdCL
+dfeffects$SEX_FEMALE_WT_90 <-  (90/70)^dfeffects$dWTdCL
+dfeffects$SEX_Male_WT_70 <- dfeffects$dSexdCL
+dfeffects$SEX_Male_WT_90 <- dfeffects$dSexdCL*(90/70)^dfeffects$dWTdCL
+dfeffects$BSV_REF<-  sample(CLBSVdistribution$CLBSV, nuncertainty)
 
 dfeffects<- dfeffects[,c("SEX_FEMALE_WT_50",
                          "SEX_FEMALE_WT_90",
                          "SEX_Male_WT_70",
                          "SEX_Male_WT_90",
                          "REF",
-                         "BSV")]
+                         "BSV_REF")]
 
 
-dflong <- tidyr::gather(dfeffects)
-ggplot2::ggplot(dflong,ggplot2::aes(x=value,y=key,fill=factor(..quantile..)))+
+dflong <- tidyr::gather(dfeffects,key,value,-REF)
+ggplot(dflong,aes(x=value,y=key,fill=factor(..quantile..)))+
 ggridges::stat_density_ridges(
   geom = "density_ridges_gradient", calc_ecdf = TRUE,
   quantile_lines = TRUE, rel_min_height = 0.01,
   quantiles = c(0.05,0.5, 0.95)) +
-  ggplot2::scale_fill_manual(
+  scale_fill_manual(
     name = "Probability", values = c("#FF0000A0", "white","white", "#0000FFA0"),
     labels = c("(0, 0.05]", "(0.05, 0.5]","(0.5, 0.95]", "(0.95, 1]")
   )+
-      ggplot2::annotate(
+      annotate(
         "rect",
         xmin = 0.8,
         xmax = 1.25,
@@ -139,32 +168,17 @@ ggridges::stat_density_ridges(
         ymax = Inf,
         fill = "gray",alpha=0.4
       )+
-  ggplot2::geom_vline(
-      ggplot2::aes(xintercept = 1),
+  geom_vline(
+      aes(xintercept = 1),
       size = 1
     )+
-  ggplot2::theme_bw()+
-  ggplot2::labs(x="Effects Relative to parameter reference value",y="")
-
-## ----fig.width= 7-------------------------------------------------------------
-ggplot2::ggplot(dfeffects)+
-  ggplot2::geom_density(ggplot2::aes(x=REF,y=..scaled..,col="a.Uncertainty\nRSE=5%"))+
-  ggplot2::geom_density(data=dfcovlong,
-                        ggplot2::aes(x=(value/70)^0.75 ,
-                                y=..scaled..,col="b.Weight\nMean=70 kg, sd=15 kg"))+
-  ggplot2::geom_density(data=CLBSVdistribution ,ggplot2::aes(x=CLBSV,
-                                     y=..scaled..,col="c.Between subject variability\nCV=30%"))+
-  ggplot2::theme_bw(base_size = 16)+
-  ggplot2::theme(axis.text.y = ggplot2::element_blank(),
-        axis.ticks.y = ggplot2::element_blank())+
-  ggplot2::scale_x_continuous(breaks=c(0.25,0.5,0.8,1,1.25,1.5,2,3))+
-  ggplot2::coord_cartesian(xlim=c(0.25,2))+
-  ggplot2::labs(color="",x="Effects Relative to parameter reference value",y= "Scaled Density")
-
+  theme_bw()+
+  labs(x="Effects Relative to parameter reference value",y="")
 
 ## -----------------------------------------------------------------------------
 dfeffects$SEX_Male_WT_90<- NULL
-dfeffectslong<- tidyr::gather(dfeffects)
+dfeffects$REF <- 1
+dfeffectslong<- gather(dfeffects)
 dfeffectslong<- dplyr::group_by(dfeffectslong,key)
 dfeffectslongsummaries<- dplyr::summarise(dfeffectslong,mid=quantile(value,0.5),
                                    lower=quantile(value,0.05),
@@ -200,36 +214,36 @@ plotdata$covname <- as.factor(plotdata$covname)
 plotdata$covname <- reorder(plotdata$covname , c(3,4,4,2,1,1))
 
 plotdata$label <- reorder(as.factor(plotdata$label) , c(1,3,2,4,5,6))
-  ggplot2::ggplot(data = plotdata, ggplot2::aes_string(
+  ggplot(data = plotdata[plotdata$covname!="REF",], aes_string(
       y = "label",
       x = "mid",
       xmin = "lower",
       xmax = "upper"
     )) +
-    ggstance::geom_pointrangeh(
-      position = ggstance::position_dodgev(height = 0.75),
-      ggplot2::aes(color = "90 %CI\nCovariate Effects"),
+      geom_pointrange(
+      aes(color = "90 %CI\nCovariate Effects"),
       size = 1,
       alpha = 1
     )+
-  ggplot2::annotate("rect", xmin = min(0.8), 
+  annotate("rect", xmin = min(0.8), 
       xmax = max(1.25), ymin = -Inf, ymax = Inf, fill = "gray",alpha=0.1)+
-  ggplot2::geom_vline(ggplot2::aes(xintercept = 1,linetype="Reference"))+ 
-  ggplot2::facet_grid(covname~.,scales="free_y",switch="y")+
-  ggplot2::labs(y="",x="Effects Relative to Reference Value",
+  geom_vline(aes(xintercept = 1,linetype="Reference"))+ 
+  facet_grid(covname~.,scales="free_y",switch="y")+
+  labs(y="",x="Effects Relative to Reference Value",
                 colour="",linetype="")+
-  ggplot2::theme_bw()
+  theme_bw()+
+    scale_color_manual(values=c("blue"))
 
 ## ----dpi = 72-----------------------------------------------------------------
 png("./coveffectsplot.png",width =9 ,height = 6,units = "in",res=72)
- coveffectsplot::forest_plot(plotdata,
+ coveffectsplot::forest_plot(plotdata[plotdata$covname!="REF",],
             ref_area = c(0.8, 1/0.8),
             x_facet_text_size = 13,
             y_facet_text_size = 13,
             interval_legend_text = "Median (points)\n90% CI (horizontal lines)",
             ref_legend_text = "Reference (vertical line)\n+/- 20% ratios (gray area)",
             area_legend_text = "Reference (vertical line)\n+/- 20% ratios (gray area)",
-            xlabel = "Fold Change Relative to Parameter",
+            xlabel = "Fold Change Relative to a 70kg Woman",
             facet_formula = "covname~.",
             facet_switch = "both",
             facet_scales = "free",
@@ -330,10 +344,10 @@ png("./coveffectsplot2.png",width =9 ,height = 6,units = "in",res=72)
             return_list = TRUE)
 egg::ggarrange(
       plotlist[[1]]+ 
-   ggplot2::labs(x= expression(paste("Changes Relative to ",
+   labs(x= expression(paste("Changes Relative to ",
                                      CL["subscript"]^alpha["beta"], " Reference"),
                                sep=""))+
-      ggplot2::theme(strip.text.y =  ggplot2::element_text(colour="blue")),
+      theme(strip.text.y =  element_text(colour="blue")),
        plotlist[[2]] ,
       nrow = 1,
       widths = c(4, 1)
